#!/bin/sh

hostname -f | fgrep "." > /dev/null
if [ $? -ne 0 ]; then
    echo "error, command 'hostname -f' does not return domainname" 1>&2
    exit 1
fi

which ruby > /dev/null 2>&1
if [ $? -ne 0 ]; then
    echo "error, ruby binary not in path" 1>&2
    exit 1
fi

which puppet > /dev/null 2>&1
if [ $? -ne 0 ]; then
    echo "error, puppet binary not in path" 1>&2
    exit 1
fi

if [ -s /etc/puppet/puppet.conf ]; then
    mv /etc/puppet/puppet.conf /etc/puppet/puppet.conf.orig
fi

FQDN="$(hostname -f)"

mkdir -p /etc/puppet/manifests/node

cat > /etc/puppet/manifests/site.pp << EOF
import "node/*.pp"

\$puppet_server = "${FQDN}"
EOF

cat > /etc/puppet/manifests/node/${FQDN}.pp << EOF
node "${FQDN}" {

    include puppet::server::webrick
    include puppet::manual

}
EOF

puppet cert --keylength 4096 --list
puppet apply --no-report /etc/puppet/manifests/site.pp
